Grantee class

Container for the person being granted permissions.

Constructors

Grantee(String? displayName, String? emailAddress, String? iD, String? type, String? uRI)
Grantee.fromXml(XmlElement? xml)

Properties

displayName ↔ String?
Screen name of the grantee.
getter/setter pair
emailAddress ↔ String?
Email address of the grantee.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iD ↔ String?
The canonical user ID of the grantee.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of grantee
getter/setter pair
uRI ↔ String?
URI of the grantee group.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) → bool
The equality operator.
inherited