LifecycleExpiration class

Container for the expiration for the lifecycle of the object.

Constructors

LifecycleExpiration(DateTime? date, int? days, bool? expiredObjectDeleteMarker)
LifecycleExpiration.fromXml(XmlElement? xml)

Properties

date ↔ DateTime?
Indicates at what date the object is to be moved or deleted. Should be in GMT ISO 8601 Format.
getter/setter pair
days ↔ int?
Indicates the lifetime, in days, of the objects that are subject to the rule. The value must be a non-zero positive integer.
getter/setter pair
expiredObjectDeleteMarker ↔ bool?
Indicates whether Amazon S3 will remove a delete marker with no noncurrent versions. If set to true, the delete marker will be expired; if set to false the policy takes no action. This cannot be specified with Days or Date in a Lifecycle Expiration Policy.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) → bool
The equality operator.
inherited