S3Location class

Describes an Amazon S3 location that will receive the results of the restore request.

Constructors

S3Location(Grant? accessControlList, String? bucketName, String? cannedACL, Encryption? encryption, String? prefix, String? storageClass, Tagging? tagging, MetadataEntry? userMetadata)
S3Location.fromXml(XmlElement? xml)

Properties

accessControlList ↔ Grant?
A list of grants that control access to the staged results.
getter/setter pair
bucketName ↔ String?
The name of the bucket where the restore results will be placed.
getter/setter pair
cannedACL ↔ String?
The canned ACL to apply to the restore results.
getter/setter pair
encryption ↔ Encryption?
Contains the type of server-side encryption used.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
prefix ↔ String?
The prefix that is prepended to the restore results for this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageClass ↔ String?
The class of storage used to store the restore results.
getter/setter pair
tagging ↔ Tagging?
The tag-set that is applied to the restore results.
getter/setter pair
userMetadata ↔ MetadataEntry?
A list of metadata to store with the restore results in S3.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXml() → XmlNode

Operators

operator ==(Object other) → bool
The equality operator.
inherited